Skip to contents

Deprecated a wrapper for kewr::search_powo. Kew's POWO search API now blocks this style of programmatic request (returns HTTP 403 regardless of client or origin), so this function can no longer reach its data source. Use wcvp_searcher instead, after setting up a local taxonomy backbone with wcvp_update and TaxUnpack.

Usage

powo_searcher(x)

Arguments

x

a vector of species names to submit, these should have clean spelling notes: results are observed to fail for valid infraspecies on Kew's end, and they seem not to mention valid infraspecies.

Examples

if (FALSE) { # \dontrun{
library(dplyr)
pow_results <- lapply(
      c('Linnaea borealis var. borealis', 'Linnaea borealis var. americana',
      'Astragalus purshii', 'Pinus ponderosa'),
      powo_searcher) |>
   dplyr::bind_rows()
head(pow_results)
} # }