This function is run on the WCVP compressed archive downloaded by 'wcvp_update',
and requires some input from the user which specifies a geographic area to establish a
taxonomic look up table for. Writes four lookup tables: a species catalog, an
infraspecific taxa catalog (varieties and subspecies), a family catalog, and a
global (unfiltered by geography) taxon ID index used by wcvp_searcher
to resolve synonyms to their currently accepted name.
Arguments
- path
Character vector. Location to where taxonomic data should be saved, we recommend a subdirectory in the same folder, and at the same level, as the geographic data.
- bound
Dataframe of x and y coordinates, same argument as to
data_setup. Coordinates assumed in WG84, NAD83, or googles absurd projection. Coordinate specifications are very precise later in the process, but at this level any of these three are effectively equivalent.